@@ -11,7 +11,7 @@ import json
 import numpy as np
 import tensorflow as tf
 from tensorflow.keras import backend as K
-from tensorflow.keras.layers import Input, Embedding
+from tensorflow.keras.layers import Input, Embedding, CategoryEncoding
 from tensorflow.keras.models import Model, load_model
 
 __author__ = "Tobias Hermann"
@@ -154,6 +154,10 @@ def gen_test_data(model):
                 input_layer._outbound_nodes[0].outbound_layer, Embedding):
             random_fn = lambda size: np.random.randint(
                 0, input_layer._outbound_nodes[0].outbound_layer.input_dim, size)
+        elif input_layer._outbound_nodes and isinstance(
+                input_layer._outbound_nodes[0].outbound_layer, CategoryEncoding):
+            random_fn = lambda size: np.random.randint(
+                0, input_layer._outbound_nodes[0].outbound_layer.num_tokens, size)
         else:
             random_fn = np.random.normal
         try:
@@ -516,7 +520,13 @@ def show_resizing_layer(layer):
 
 def show_category_encoding_layer(layer):
     """Serialize CategoryEncoding layer to dict"""
-    assert layer.output_mode in ["multi_hot", "count"]
+    assert layer.output_mode in ["multi_hot", "count", "one_hot"]
+
+
+def show_attention_layer(layer):
+    """Serialize Attention layer to dict"""
+    assert layer.score_mode in ["dot"]
+    assert layer.use_scale is False
 
 
 def get_layer_functions_dict():
@@ -542,6 +552,7 @@ def get_layer_functions_dict():
         'UpSampling2D': show_upsampling2d_layer,
         'Resizing': show_resizing_layer,
         'CategoryEncoding': show_category_encoding_layer,
+        'Attention': show_attention_layer,
     }
 
 
@@ -620,8 +631,6 @@ def get_layer_weights(layer, name):
     layer_type = type(layer).__name__
     if hasattr(layer, 'data_format'):
         assert layer.data_format == 'channels_last'
-    if hasattr(layer, 'keepdims'):  # Pooling layers
-        assert not layer.keepdims
 
     show_func = get_layer_functions_dict().get(layer_type, None)
     shown_layer = None
