@@ -25,6 +25,7 @@ from tensorflow.keras.layers import Multiply, Add, Subtract, Average, Maximum, M
 from tensorflow.keras.layers import Permute, Reshape, RepeatVector
 from tensorflow.keras.layers import SeparableConv2D, DepthwiseConv2D
 from tensorflow.keras.layers import ZeroPadding3D, Cropping3D
+from tensorflow.keras.layers import Attention
 from tensorflow.keras.models import Model, load_model, Sequential
 
 __author__ = "Tobias Hermann"
@@ -139,10 +140,13 @@ def get_test_model_exhaustive():
         (2, 1, 1, 1, 1),
         (1, 1, 4, 1, 6),
         (1, 3, 1, 5, 1),
-        (2, 1, 4, 1, 1),
-        (1,),  # 46
+        (2, 1, 4, 1, 1), # 45
+        (1,),
         (3, 1),
         (6, 5, 4, 3, 2),
+        (5, 4),
+        (7, 4),  # 50
+        (7, 4),
     ]
 
     inputs = [Input(shape=s) for s in input_shapes]
@@ -160,6 +164,8 @@ def get_test_model_exhaustive():
     outputs.append(AveragePooling1D(2, strides=2, padding='same')(inputs[6]))
     outputs.append(GlobalMaxPooling1D()(inputs[6]))
     outputs.append(GlobalAveragePooling1D()(inputs[6]))
+    outputs.append(GlobalMaxPooling1D(keepdims=True)(inputs[6]))
+    outputs.append(GlobalAveragePooling1D(keepdims=True)(inputs[6]))
 
     outputs.append(Normalization(axis=None, mean=2.1, variance=2.2)(inputs[4]))
     outputs.append(Normalization(axis=-1, mean=2.1, variance=2.2)(inputs[6]))
@@ -199,6 +205,10 @@ def get_test_model_exhaustive():
     outputs.append(GlobalAveragePooling3D()(inputs[2]))
     outputs.append(GlobalMaxPooling2D()(inputs[4]))
     outputs.append(GlobalMaxPooling3D()(inputs[2]))
+    outputs.append(GlobalAveragePooling2D(keepdims=True)(inputs[4]))
+    outputs.append(GlobalAveragePooling3D(keepdims=True)(inputs[2]))
+    outputs.append(GlobalMaxPooling2D(keepdims=True)(inputs[4]))
+    outputs.append(GlobalMaxPooling3D(keepdims=True)(inputs[2]))
 
     outputs.append(CenterCrop(4, 5)(inputs[4]))
     outputs.append(CenterCrop(5, 6)(inputs[4]))
@@ -381,6 +391,9 @@ def get_test_model_exhaustive():
     outputs.append(Multiply()([inputs[43], inputs[44]]))
     outputs.append(Multiply()([inputs[44], inputs[45]]))
 
+    outputs.append(Attention(use_scale=False, score_mode='dot')([inputs[49], inputs[50]]))
+    outputs.append(Attention(use_scale=False, score_mode='dot')([inputs[49], inputs[50], inputs[51]]))
+
     shared_conv = Conv2D(1, (1, 1),
                          padding='valid', name='shared_conv', activation='relu')
 
@@ -493,11 +506,13 @@ def get_test_model_embedding():
 
     input_dims = [
         1023,  # maximum integer value in input data
-        255
+        255,
+        15,
     ]
     input_shapes = [
         (100,),  # must be single-element tuple (for sequence length)
-        (1000,)
+        (1000,),
+        (1,),
     ]
     assert len(input_dims) == len(input_shapes)
     output_dims = [8, 3]  # embedding dimension
@@ -505,7 +520,7 @@ def get_test_model_embedding():
     inputs = [Input(shape=s) for s in input_shapes]
 
     outputs = []
-    for k in range(0, len(input_shapes)):
+    for k in range(2):
         embedding = Embedding(input_dim=input_dims[k], output_dim=output_dims[k])(inputs[k])
         lstm = LSTM(
             units=4,
@@ -515,12 +530,11 @@ def get_test_model_embedding():
 
         outputs.append(lstm)
 
-    outputs.append(CategoryEncoding(1023, output_mode='multi_hot', sparse=False)(inputs[0]))
-    outputs.append(CategoryEncoding(1234, output_mode='count', sparse=False)(inputs[0]))
+    outputs.append(CategoryEncoding(1024, output_mode='multi_hot', sparse=False)(inputs[0]))
+    outputs.append(CategoryEncoding(1024, output_mode='count', sparse=False)(inputs[0]))
+    outputs.append(CategoryEncoding(16, output_mode='one_hot', sparse=False)(inputs[2]))
     # Error: Value passed to parameter 'values' has DataType float32 not in list of allowed values: int32, int64
     # outputs.append(CategoryEncoding(1023, output_mode='multi_hot', sparse=True)(inputs[0]))
-    # Error: When output_mode is not `'int'`, maximum supported output rank is 2. Received output_mode one_hot and input shape (None, 100), which would result in output rank 3.
-    # outputs.append(CategoryEncoding(1234, output_mode='one_hot', sparse=False)(inputs[0]))
 
     model = Model(inputs=inputs, outputs=outputs, name='test_model_embedding')
     model.compile(loss='mse', optimizer='adam')
